netapp_ontap.models.storage_pool_spare_allocation_unit API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_pool_spare_allocation_unit`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StoragePoolSpareAllocationUnitSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StoragePoolSpareAllocationUnit object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `available_size: Size GET`

    The usable capacity of this set of allocation units.

  `count: Size GET POST PATCH`

    The number of spare allocation units on this node.

  `node: Node GET POST PATCH`

    The node field of the storage_pool_spare_allocation_unit.

  `size: Size GET`

    Size of each allocation unit.

  `syncmirror_pool: str GET`

    The RAID SyncMirror Pool to which this allocation unit is assigned.

    Valid choices:

    - pool0
    - pool1